//
//                     Pervasive Discovery Protocol
//                          Copyright (C) 2005
//
//    Jos Carlos Perea barreiro         Celeste Campo Vzquez
//      (jperea[at]it.uc3m.es)          (celeste[at]it.uc3m.es)
//
// This library is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License as published
// by the Free Software Foundation; either version 2.1 of the License, or
// (at your option) any later version.
//
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the
// Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
//
//
// Contact the authors at:
//
//    Jos Carlos Perea Barreiro (jperea [at]it.uc3m.es)
//    Celeste Campo Vazquez      (celeste[at]it.uc3m.es)
//
//        Universidad Carlos III de Madrid
//        Departamento de Ingeniera Telemtica
//        Av. Universidad, 30
//        Edif. Torres Quevedo.
//        (28911) Legans - Madrid - SPAIN
//
//
/////////////////////////////////////////////////////////////////////////////

/**
  * Provides the classes and interfaces relating to the reference implementation
  * for Pervasive Discovery Protocol (PDP).
  * <p>
  * This protocol was designed within the Departamento de Ingeniera
  * Telemtica at the Universidad Carlos III de Madrid by
  * Celeste Campo Vzquez (celeste[at]it.uc3m.es) and programmed by
  * Jos Carlos Perea Barreiro (jperea[at]it.uc3m.es)
  */
package com.uc3m.it.pfc.pdp;

/**
  *
  * Basic inherited exception class. See {@link java.lang.Exception}
  *
  * @author Celeste Campo Vzquez (celeste[at]it.uc3m.es)
  * @author Jos Carlos Perea Barreiro (jperea[at]it.uc3m.es)
  * @version initial
  */

public class PDPException extends Exception
{
    public static final byte PDP_GENERAL_ERROR = 0x00;
    public static final byte PARSING_ERROR = 0x01;
    public static final byte NETWORK_ERROR = 0x03;
    public static final byte UA_BUSY       = 0x04;
    public static final byte UA_DISABLED   = 0x05;

    String data;
    int code;

    public PDPException ( int code, String data )
    {
        super ( );
        this.code = code;
        this.data = data;
    }

    public PDPException ( int code )
    {
        this.code = code;
        this.data = defaultData ( );
    }

    public PDPException ( String data )
    {
        this( 0x00, data );
    }

    private String defaultData ( )
    {
        String r;

        switch ( code )
        {
            case PARSING_ERROR:
                r = "Parsing error";
                break;

            case NETWORK_ERROR:
                r = "Network error";
                break;

            case UA_BUSY:
                r = "UA is working. Get the reply or stop UA.";
                break;

            case UA_DISABLED:
                r = "UA is disabled.";
                break;

            case PDP_GENERAL_ERROR:
            default:
                r = "Internal error";
                break;
        }

        return r;
    }

    public String toString ( )
    {
        return code + ". " + data;
    }

    /**
     *
     * @uml.property name="data"
     */
    public String getData() {
        return data;
    }

}
