//
//                     Pervasive Discovery Protocol
//                          Copyright (C) 2005
//
//    Jos Carlos Perea barreiro         Celeste Campo Vzquez
//      (jperea[at]it.uc3m.es)          (celeste[at]it.uc3m.es)
//
// This library is free software; you can redistribute it and/or modify it
// under the terms of the GNU Lesser General Public License as published
// by the Free Software Foundation; either version 2.1 of the License, or
// (at your option) any later version.
//
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the
// Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
//
//
// Contact the authors at:
//
//    Jos Carlos Perea Barreiro (jperea [at]it.uc3m.es)
//    Celeste Campo Vazquez      (celeste[at]it.uc3m.es)
//
//        Universidad Carlos III de Madrid
//        Departamento de Ingeniera Telemtica
//        Av. Universidad, 30
//        Edif. Torres Quevedo.
//        (28911) Legans - Madrid - SPAIN
//
//
/////////////////////////////////////////////////////////////////////////////

/**
  * Provides the classes and interfaces relating to the reference
  * implementation for Pervasive Discovery Protocol (PDP).
  * <p>
  * This protocol was designed within the Departamento de Ingeniera
  * Telemtica at the Universidad Carlos III de Madrid by
  * Celeste Campo Vzquez (celeste[at]it.uc3m.es) and programmed by
  * Jos Carlos Perea Barreiro (jperea[at]it.uc3m.es)
  */
package com.uc3m.it.pfc.pdp;

/**
  *
  * The PDPService interface implements a framework to define a Service
  * for Pervasive Discovery Protocol. It includes 7 methods to manage
  * a Service entity and work within the protocol; on this implementation
  * the class {@link ServiceURL} acts as the Service-defining object.
  *
  *
  * @author Celeste Campo Vzquez (celeste[at]it.uc3m.es)
  * @author Jos Carlos Perea Barreiro (jperea[at]it.uc3m.es)
  * @version initial
  */
public interface PDPService
{

    /**
      * Returns a string representing the service identifier
      */
    String getService ( );


    /**
      * Returns a string containning the url to reach the Service
      */
    String getURL ( );


    /**
      * Returns a string containning the complete attributes to define
      * the service
      */
    String getAttributes ( );


    /**
      * Returns a string containning an univocal representation for
      * the service
      */
    String getDescription ( );


    /**
      * Compares the service with the identifier given on the parameter
      * and returns the result of the comparison
      *
      * @param service Identifier to compare the Service with
      * @return A boolean value giving the result of the comparison
      */
    boolean equals ( String service );


    /**
      * Compares the service (this) with the service given on the
      * parameter and returns the result of the comparison
      *
      * @param service PDPService object containning the Service to compare
      *     with
      * @return A boolean value giving the result of the comparison
      */
    boolean equals ( PDPService service );


    /**
      * Returns a byte representation of the univocal description for
      * the Service
      *
      * @return A byte array containning the univocal description for
      *     this service
      */
    byte [] getBytes ( );

}